;
;   Module name      :	ExampleLogObj.au3
;
;   Sw requirements  :	LogObj.au3 ver. 1.0, Constants.au3
;
;   Parameters       :	None
;   Notes - usage    :	None
;


;--- Global directives -----------------------------------------------------------------------------



Opt("TrayIconDebug", 1)

Opt("MustDeclareVars", 1)
Opt("GUICloseOnESC", 0)



;--- Include files ---------------------------------------------------------------------------------



#include "LogObj.au3"
#include <Constants.au3>



;--- Global constants ------------------------------------------------------------------------------



const $FILE_NAME = "ExampleLogObj.au3"



;--- Global variables ------------------------------------------------------------------------------



global $Debugging = True			; Set to False on debugging ended

global $Debug_h, $Oper_h, $Usage_h	; Log object handles
global $File_path, $File_ver
global $Tot = 0						; Number of examined files



;--- Functions code --------------------------------------------------------------------------------



func ShowMsg($msg, $stop = False)
;---
; Displays a message in a Message Box and optionally stop the script.
;
; $msg	message
; $stop	if True, the execution of the script is stopped
; ret	nothing
;---
	if ($stop) then
		MsgBox(0 + 16, $FILE_NAME, $msg)			; 0 + 16 = $MB_OK + $MB_ICONHAND
		Exit
	else
		MsgBox(0 + 64, $FILE_NAME, $msg)			; 0 + 64 = $MB_OK + $MB_ICONASTERISK
	endif
endfunc



;--- Main code -------------------------------------------------------------------------------------



if ($Debugging) then				; If not opened, calls to LOWrite for Debug.log will be ignored
	$Debug_h = LOInit($LO_FILE_MODE, "%TEMP%\Debug.log")
	if (@error) then
		ShowMsg("Cannot write to 'Debug.log' in temp dir.", True)
	endif
endif

$Oper_h = LOInit($LO_FILE_MODE, "Oper.log")
if (@error) then
	ShowMsg("Cannot write to 'Oper.log' in current dir.", True)
endif

$Usage_h = LOInit($LO_SYSLOG_MODE, "@192.168.0.1:514")
if (@error) then
	ShowMsg("Cannot open Udp Syslog", True)
endif

LOWrite($Usage_h, "Start")								; Log start of the program to the remote server
LOWrite($Debug_h, "Start")								; On debug log, too

do
	$File_path = FileOpenDialog($FILE_NAME, "", "Executable files (*.exe)|All (*.*)", 1 + 2)
	LOWrite($Debug_h, "File chosen: '" & $File_path & "'")
	if ($File_path <> "") then
		$Tot += 1
		LOWrite($Debug_h, "Begin of file " & $Tot)
		$File_ver = FileGetVersion($File_path)
		if ($File_ver == "0.0.0.0") then
			ShowMsg("The file has no version information")
			LOWrite($Debug_h, "The file has no version information: '" & $File_ver & "'")
		else
			ShowMsg("File:" & @Tab & $File_path & @LF & "Version:" & @Tab & $File_ver)
			LOWrite($Debug_h, "Version read: '" & $File_ver & "'")
		endif
		LOWrite($Oper_h, "File '" & $File_path & "', ver. " & $File_ver)	; Log short data on Oper.log
	endif
until ($File_path == "")

LOWrite($Usage_h, "End (" & $Tot & " files examined)")	; Log end of the program to the remote server
LOWrite($Debug_h, "End")								; On debug log, too

LoDone($Debug_h)
LoDone($Oper_h)
LoDone($Usage_h)
